@@ -12,6 +12,8 @@ use warnings;
 use Mail::DKIM::PrivateKey;
 use Mail::DKIM::ARC::MessageSignature;
 use Mail::DKIM::ARC::Seal;
+use Mail::AuthenticationResults::Parser;
+use Mail::AuthenticationResults::Header::AuthServID;
 
 =head1 NAME
 
@@ -157,7 +159,7 @@ The list of headers signed by default is as follows
 package Mail::DKIM::ARC::Signer;
 use base 'Mail::DKIM::Common';
 use Carp;
-our $VERSION = 0.54;
+our $VERSION = 0.55;
 
 # PROPERTIES
 #
@@ -248,8 +250,9 @@ sub finish_header {
     foreach my $header ( @{ $self->{headers} } ) {
         $header =~ s/[\r\n]+$//;
         if ( $header =~ m/^Authentication-Results:/ ) {
-            my ( $ardom, $arval ) = $header =~
-              m/^Authentication-Results:\s*([-.0-9a-z]+)\s*;\s*(.*)/is;
+            my ( $arval ) = $header =~ m/^Authentication-Results:[^;]*;\s*(.*)/is;
+            my $parsed = Mail::AuthenticationResults::Parser->new->parse( $header );
+            my $ardom = $parsed->value->value;
 
             next
               unless "\L$ardom" eq $self->{SrvId};   # make sure it's our domain
